@@ -23,9 +23,9 @@ import java.util.Arrays;
 import java.util.HashMap;
 import java.util.Map;
 
-import javax.servlet.ServletOutputStream;
-import javax.servlet.http.HttpServletResponse;
-import javax.servlet.http.HttpServletResponseWrapper;
+import jakarta.servlet.ServletOutputStream;
+import jakarta.servlet.http.HttpServletResponse;
+import jakarta.servlet.http.HttpServletResponseWrapper;
 
 /**
  * Implementation of <b>HttpServletResponseWrapper</b> that works with
@@ -82,7 +82,7 @@ public class CompressionServletResponseWrapper
     /**
      * The compression buffer size
      */
-    protected int compressionBuffer = 8192;  // 8 KiB default
+    protected int compressionBuffer = 8192;  // 8KB default
 
     /**
      * The mime types to compress
@@ -188,7 +188,7 @@ public class CompressionServletResponseWrapper
                     stream.close();
                 }
             }
-        } catch (IOException ignore) {
+        } catch (IOException e) {
             // Ignore
         }
     }
